# yaml-to-object

[![Build Status](https://travis-ci.com/FebruaryBreeze/yaml-to-object.svg?branch=master)](https://travis-ci.com/FebruaryBreeze/yaml-to-object)

YAML to Python object, friendly to IDE
